==> zio-aws-athena_3-5.17.123.1-sources.jar: zio/aws/athena/model/CreateDataCatalogRequest.scala <==
package zio.aws.athena.model
import zio.aws.athena.model.primitives.{
  ParametersMapValue,
  KeyString,
  DescriptionString,
  CatalogNameString
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateDataCatalogRequest(
    name: CatalogNameString,
    `type`: zio.aws.athena.model.DataCatalogType,
    description: Option[DescriptionString] = None,
    parameters: Option[Map[KeyString, ParametersMapValue]] = None,
    tags: Option[Iterable[zio.aws.athena.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.athena.model.CreateDataCatalogRequest = {
    import CreateDataCatalogRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.athena.model.CreateDataCatalogRequest
      .builder()
      .name(CatalogNameString.unwrap(name): java.lang.String)
      .`type`(`type`.unwrap)
      .optionallyWith(
        description.map(value =>
          DescriptionString.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(
        parameters.map(value =>
          value
            .map({ case (key, value) =>
              (KeyString.unwrap(key): java.lang.String) -> (ParametersMapValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.parameters)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.athena.model.CreateDataCatalogRequest.ReadOnly =
    zio.aws.athena.model.CreateDataCatalogRequest.wrap(buildAwsValue())
}
object CreateDataCatalogRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.athena.model.CreateDataCatalogRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.athena.model.CreateDataCatalogRequest =
      zio.aws.athena.model.CreateDataCatalogRequest(
        name,
        `type`,
        description.map(value => value),
        parameters.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def name: CatalogNameString
    def `type`: zio.aws.athena.model.DataCatalogType
    def description: Option[DescriptionString]
    def parameters: Option[Map[KeyString, ParametersMapValue]]
    def tags: Option[List[zio.aws.athena.model.Tag.ReadOnly]]
    def getName: ZIO[Any, Nothing, CatalogNameString] = ZIO.succeed(name)
    def getType: ZIO[Any, Nothing, zio.aws.athena.model.DataCatalogType] =
      ZIO.succeed(`type`)
    def getDescription: ZIO[Any, AwsError, DescriptionString] =
      AwsError.unwrapOptionField("description", description)
    def getParameters: ZIO[Any, AwsError, Map[KeyString, ParametersMapValue]] =
      AwsError.unwrapOptionField("parameters", parameters)
    def getTags: ZIO[Any, AwsError, List[zio.aws.athena.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.athena.model.CreateDataCatalogRequest
  ) extends zio.aws.athena.model.CreateDataCatalogRequest.ReadOnly {
    override val name: CatalogNameString =
      zio.aws.athena.model.primitives.CatalogNameString(impl.name())
    override val `type`: zio.aws.athena.model.DataCatalogType =
      zio.aws.athena.model.DataCatalogType.wrap(impl.`type`())
    override val description: Option[DescriptionString] = scala
      .Option(impl.description())
      .map(value => zio.aws.athena.model.primitives.DescriptionString(value))
    override val parameters: Option[Map[KeyString, ParametersMapValue]] = scala
      .Option(impl.parameters())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.athena.model.primitives.KeyString(
              key
            ) -> zio.aws.athena.model.primitives.ParametersMapValue(value)
          })
          .toMap
      )
    override val tags: Option[List[zio.aws.athena.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.athena.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.athena.model.CreateDataCatalogRequest
  ): zio.aws.athena.model.CreateDataCatalogRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-athena_3-6.20.78.2-sources.jar: zio/aws/athena/model/CreateDataCatalogRequest.scala <==
package zio.aws.athena.model
import zio.aws.athena.model.primitives.{
  ParametersMapValue,
  KeyString,
  DescriptionString,
  CatalogNameString
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateDataCatalogRequest(
    name: CatalogNameString,
    `type`: zio.aws.athena.model.DataCatalogType,
    description: Optional[DescriptionString] = Optional.Absent,
    parameters: Optional[Map[KeyString, ParametersMapValue]] = Optional.Absent,
    tags: Optional[Iterable[zio.aws.athena.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.athena.model.CreateDataCatalogRequest = {
    import CreateDataCatalogRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.athena.model.CreateDataCatalogRequest
      .builder()
      .name(CatalogNameString.unwrap(name): java.lang.String)
      .`type`(`type`.unwrap)
      .optionallyWith(
        description.map(value =>
          DescriptionString.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(
        parameters.map(value =>
          value
            .map({ case (key, value) =>
              (KeyString.unwrap(key): java.lang.String) -> (ParametersMapValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.parameters)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.athena.model.CreateDataCatalogRequest.ReadOnly =
    zio.aws.athena.model.CreateDataCatalogRequest.wrap(buildAwsValue())
}
object CreateDataCatalogRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.athena.model.CreateDataCatalogRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.athena.model.CreateDataCatalogRequest =
      zio.aws.athena.model.CreateDataCatalogRequest(
        name,
        `type`,
        description.map(value => value),
        parameters.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def name: CatalogNameString
    def `type`: zio.aws.athena.model.DataCatalogType
    def description: Optional[DescriptionString]
    def parameters: Optional[Map[KeyString, ParametersMapValue]]
    def tags: Optional[List[zio.aws.athena.model.Tag.ReadOnly]]
    def getName: ZIO[Any, Nothing, CatalogNameString] = ZIO.succeed(name)
    def getType: ZIO[Any, Nothing, zio.aws.athena.model.DataCatalogType] =
      ZIO.succeed(`type`)
    def getDescription: ZIO[Any, AwsError, DescriptionString] =
      AwsError.unwrapOptionField("description", description)
    def getParameters: ZIO[Any, AwsError, Map[KeyString, ParametersMapValue]] =
      AwsError.unwrapOptionField("parameters", parameters)
    def getTags: ZIO[Any, AwsError, List[zio.aws.athena.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.athena.model.CreateDataCatalogRequest
  ) extends zio.aws.athena.model.CreateDataCatalogRequest.ReadOnly {
    override val name: CatalogNameString =
      zio.aws.athena.model.primitives.CatalogNameString(impl.name())
    override val `type`: zio.aws.athena.model.DataCatalogType =
      zio.aws.athena.model.DataCatalogType.wrap(impl.`type`())
    override val description: Optional[DescriptionString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value => zio.aws.athena.model.primitives.DescriptionString(value))
    override val parameters: Optional[Map[KeyString, ParametersMapValue]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parameters())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.athena.model.primitives.KeyString(
                key
              ) -> zio.aws.athena.model.primitives.ParametersMapValue(value)
            })
            .toMap
        )
    override val tags: Optional[List[zio.aws.athena.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.athena.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.athena.model.CreateDataCatalogRequest
  ): zio.aws.athena.model.CreateDataCatalogRequest.ReadOnly = new Wrapper(impl)
}
